/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_3Q_HPP_
#define _HEAVY_CONTEXT_WSTD_3Q_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlVar.h"
#include "HvControlSlice.h"
#include "HvSignalLine.h"
#include "HvControlCast.h"
#include "HvSignalBiquad.h"
#include "HvSignalVar.h"
#include "HvControlBinop.h"
#include "HvControlSystem.h"
#include "HvMath.h"
#include "HvControlIf.h"
#include "HvControlUnop.h"

class Heavy_WSTD_3Q : public HeavyContext {

 public:
  Heavy_WSTD_3Q(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_3Q();

  const char *getName() override { return "WSTD_3Q"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 6; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_cUIezvV7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1KsnFI01_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WQHKiwk2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BtpvP7q4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xT1D8SZG_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_su84DMlq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ys9jxgud_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_4hiwsXco_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MCKSVMn8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gqalfvzm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_1vmsHIjc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DJ1An2ns_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IC1UXyr0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fNewvSeq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HYmrJZ9y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1KH3sBKP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r9iDcbiS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QfgKSdpV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AS1a7e0D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pNIkAaYD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vUnOqe6W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0mxXSR57_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5vThTYXm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fZrD4Uow_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sh6w7r3G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pa2F2LGP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ktLAkGoC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2BQz9asi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KD7ppAwr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YzP0nOpC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QRCidf0Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wv6WW2Ba_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_5Y7X95fP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gsh5d0kx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zlb9OmFF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_guV7kM13_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pESETsjm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_H8ion10T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dE8zqpvG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RjBxKNot_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cAD6AdxT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rLArErhy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0owhkTZ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_OA4c9ns4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yoUCjEgz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gqPyqW5b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nvahWdhB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HgPDuIzM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qa2ju6ha_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PnTHhwdA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iH4jKjxq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_A3P5cuRs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PEYBubvP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yZkPyEzb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wTYeE4ON_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_fAOBzcHZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_K5V93tSI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HRthIZmF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FQKq9A3v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5aQSJABb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BVq9lgd9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Oo3NDynE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HumcfLvD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GpEoUOwZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AwXNXIIP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GTAfUGac_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Jm6S79dN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ADrdXS62_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cxfsmVXS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6XnKkZ3z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XWuZZxpV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J7JcQYRs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zzR1svFB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IHYASNtE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WdREiXMv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ByGDPRDF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rvCBLlo1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_cTWn5Rf0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hM9chQTo_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ZifBwXq7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aQbNrOb7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_AH8ww4dt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_w2OGn7g4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_yjtX40Wj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wPC3SQ3v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Z12gzwTn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_wKtzHOkL_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_DrIAaLaX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HJqxy73v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_2TkkBKkw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Zn1Hq1Tt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_tGUhK2fI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Dk1QwCJb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_prxoUPt1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TPDeRizz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_C7My8acg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_27xl0zya_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xYuHaQ2N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7jWMNzLP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7zut5CtL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_eM0Q8CF3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_DumALJSy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Kx9iCuLK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eLnqUE6n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mmvNfIAS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Esk3jCMv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jw97jJZi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_qukwexwU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_5VzVnm7L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s32JO4co_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QLyVDBeL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4mYbGFRV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DovnQpKf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I6AmYcpO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qIoQPiiV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QoN3I4Gh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cLRYdOrh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U7PDIwcV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y74yRI9V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rxGeenlc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8XswOpHC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nmqFbhBi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vdzu6LQy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L2EsIKcO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BOtuSODI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_464mNGuU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_T3BP61Ft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_p3XWQcvO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_X0LQGgNT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_YeVqT5nE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_G1UZuG29_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_D6SOHsoq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pMphFYPa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PmzaG30G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9nvTHhaS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HdAQRsLW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZZd7EVKw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iKqaZ6rg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EnsKT6vS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TUpipfoH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9rcXjZ7q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_juySaosg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TGgowmBQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JSWJQx9z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RM2b5Csx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4nGyKwOc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_U2Uvu5Pc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TopRBoiT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Rl1abV2Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IYBoBWH2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kuCRIe6D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HcQVQoqM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NfK3mxXU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hHA6dHTf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZprILThN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FUVCIcAC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zlUwS56B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_3od8UrZx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_S16TQTuL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PqSpCjpd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7mRvg9zg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2oSW4uRc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HZ6WGP83_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UanKq7LQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_t16fJlki_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_TNr0ZvAO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IHkhln1J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_19cQbgAU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RobUIldw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HMzMaesb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n2KTiHZO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lz4XMFQI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QRx9ehEJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fU7Q9J1P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HHxlVDOm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_prYE9sax_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_P1rhF2JN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hrQY3Isx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_17gCQywv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1EywBcGC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_fBu2ugb0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_UbEE5F4e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_S3v8KCAD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KCMsDIct_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KSrHJjE2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1WbacYbx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bOjzm0A2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PFPDA1r5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NJ50hfOr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W5AIKOVe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rymBI8dZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P1KTxKVq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GpwtMzf0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P9swUKS5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dYGyM5r7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tmS7Hb3P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1bI8iswt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lc0g5yQb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Qufgb4wd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ikDmfXZi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dnrRv1jA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WS4MPTOw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QTPksB5j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vRRb10SF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_szz5s7UI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DuVtnFoy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EhSgZdKz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_oWI2AiJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_2NmS9WNR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FxS9yUTH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gn7rnptX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JqzN50sy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bOnhr2u4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_20hmtwIx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_V0ZSpmLu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_xgW8Wju2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i0OTMGo7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N3hkwnI2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YFc7iLeM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WRDjO9pT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MQk5gk0N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WqMW9WvY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_60wyzdgF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ftpAlTv9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3lZujtZ4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wY03nKLj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ocMxscQl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0iIex6HI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lLj5ZqZR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JtUdBxM5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rxO55a3d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r5wI7XCm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RfZ2Jw2K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LgFwJY1R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ChSRPxOL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z8joyTmI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FwY3Im3P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Q9UrJwy8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_z4i0XUHL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_OwmwKMkD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_R5jv1uHN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UAY4ojDX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yNFEHRGz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1kWz4vXY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oYLz6m0f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kNnqC38d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yEJwWGEu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b0q2fhxl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hir7HkhG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F1vEUmri_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dhg8ly94_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KGmlLhry_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yQUEa8YL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yZA7g177_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ks3sUa5Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wCtbaTHO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4vKPFacn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2RDCQ4YY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4PpuKxRw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TIQplLv2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CW7pkkFZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R0LKoVkt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GzpB8M2O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jQ0hiYBh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Esi1aqXx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_IEobt35M_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_gU19ehjC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DTiWvcJg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_a1V3kPtF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_c3DQ87W7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_hCNHsc4Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_fYTQpExb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MXEil7Ia_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k2pRw2ss_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZQwvMaiE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AkpNi8Wb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_e1GZSTKD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O2B1lfEY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qv0tD9CO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O9iMPImu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yufqshcc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_b3cgc7lB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cO6BiIjA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iemllIsl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0eejBm3u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X8aKVUiU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4UnkZUXM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nV0Bk824_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9a1ne4kQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QRcWObmE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yGD2c5Tg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o7zaMfPG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tMZqMRlO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_45yHOFK2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_INjT0dDO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_84Drw3lE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SgDDUBVf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HpPRGxJ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jM8oXHYt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uVC2MiIi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_knsOEo4g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5nev20IX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aFuSjJpF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rG3V957N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_dk4sexAs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZABYhuTQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uS9jeZJv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KzFCe4yQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iawutD4j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MpNWhf0f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v5nBibl0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sk9AyX93_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_T7zuH9dC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yyquJfBB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_l08HVt5A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6zfdBu88_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_0k9k1H8D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_YqySUZwF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Htt4GBLW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k2bIUYaN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GFo88sso_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Fwpf6vHM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N6huYg6w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z4E9hFsz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o1BTglSC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l2heJiHB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gMWwBes6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3Bo5Nkap_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Oa0ba5LP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y7ivzLOc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qU3hG3Vf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GGhjsGeY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d2DLzwQX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yNq27SeB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yfQVjPCu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Y6qceCCP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sbpgB5y9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OHnTXri8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_iignx3Gg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_gl118SUM_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_euSTgymp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iiVmBfzb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_pfKHMlqn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_oMXoNEOd_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_DjVp4722_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Z5TXTVex_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_aRfdHn4B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_RWyg1Ym2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_vB9qB3MX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QxKBERj8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_wYtdebag_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kjQF4IoV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_2GFeHoo5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1njI2lqr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_TXhKJe9j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QzxaCk1o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cD8vJsEa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ooAMh5li_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZDn0D8HZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ep4c1Ldi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qDNycf9Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Kq5Sk465_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_xBRA7UOk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RZSZ8NX2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2V0Y4izh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3p06Jsuv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nTZb6w6m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nkEvDhve_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_vJ192wEY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_FC38wTJ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nl2oC9ag_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3e8A0lWo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vnNIkDfL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GQi2vcoB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0bod6czK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5ACX61E6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YhAFoJ8R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1O8QgD3C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AEbxkFJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3xT5FRPD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KRRw9Siz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7v9BoCON_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wqRD8vch_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zDUGhC4r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aI1vPQ4u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_y3ecMgaN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oYrD3ALX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0U9QLf77_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fdr0gGSy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_e6zMpMNx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_IkxobNU9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_eBo2s8Ps_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZzYR2JuA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6YjzVdCI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eG7dhB9H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R0OL8f3d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n07OmRKg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ytQMTBph_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N5Hf2p4S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h8wccjne_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lf7dty8f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2VfysnYM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UgrPaUeK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_d0PRIplq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dQ4Ga8aq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mHWLE2ft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_llDhSA3J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8SjUMoCi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VMGhv7dK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N02SOeld_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_01q8amSr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bkBo0ueb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EMBxVSiy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Zmyh8YSR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xFxsv4ZQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tcL6ayZK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LcuL1hGk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XQffKOrh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_YPvXfvaw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_tO7Blw8e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9i7I2sT9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vEjo5Tbv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZsO62d5O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GB3dlVKl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Cdh2ip34_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_0hBgKqiU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_4QO6Xg2o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yNSPjVVe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ID6kjKXr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NRUalJev_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PigsOIwM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kSNLvh0P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8l6wrzCA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kQI6oaTr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1ogATBV0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U7OzZipx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SfehNY3I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Y8tpfoPB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mp9kLysR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N1HriGTU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FuV9WI0B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_1b8Clela_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_xIASFdHC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_B0NKqChS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QYKezrod_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JpGodCbq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_StXLiDVi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wLDlEmbU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RuE4mWBF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wRVN1jrQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VbtUE1Ar_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z26JEh1R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IOBaI3JB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3WqD4raG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZcFiVV2M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KOZtplzP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4wmqiPEN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BVaDPPT8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3n89WB8L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QYJREQLv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_21JRg3p3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Wgz5xiWQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CJhbnzLC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c1CLX1pI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S9Y7bdvH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MQaR5ndl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bb7UK5cF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nxlJhdER_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_QoxqmP3J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_N9W5y27V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_akpiL3wg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lcYujyJz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sPa9hLII_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R3gvYVON_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CJzBlbU5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_2dunwfM3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Rsja1oQI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E4Dt1efc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rcFiL0lz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_duGy0c6k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k1NqZPPL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KWXyH6Tc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4lcy0245_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aXgzUYht_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OweSOtSP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gTY41RCS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qDCzAWWZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kub6441d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iSqZhIQ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gHDOIcbc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zmBOPysX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9ikqfhD9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AcwGRtI5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_d0StjQ6J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZnpTNV6M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yiGAIYEK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YPizLm0u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bJ8AhKnf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_pZRUKR1c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_eVHvlOp8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_1MYNJ9gD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Khtu1phz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FrqXzy8i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DaCJ8Tjp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ReS3Uqtm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x3V6MAXt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0Vb6saVT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NUbewmt5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OrB35BRi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2Awvtwpk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_deSQi2J1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sA4DfsYE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oYE6HqNB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bds60T7n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2QvSksGM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xDDqgk8z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RFWXSEHJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_73atBAcr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TEWGKCJH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dFFl76p7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u2BGbuzP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eD7qj5ps_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ejIxRizH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UW6W2dkh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dOqUznjH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4NtxR0j5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lHY20qsq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GiSrLIRP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_o88GGoSi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ExETt4Of_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_07PqmlgE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pOnm00Gs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_L1DlRq50_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kPJmP7TO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_27crII6x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eqpY4BBU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_vGdXi1TH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C79w3AQf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ktULEVFv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yKbzyjDc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xQTQjlyv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LeGb8oHJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sFxVbo4X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UHD1d5GE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VbDfmBy7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lQPTlMHd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2z3TmCAo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OjWbVBrq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3Gugb2qn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_aQ19JBQO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nmMEGfHY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7i0kAQyB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PiS0RvqL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_F3RHDmo6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5sKY9880_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0whNdDET_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YGyxY8kz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vtc5bGpE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bCAlAxRZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_20vKAKem_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8eZXjP9Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YyvDhqZy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3mo4gYW3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_SYfO7hc8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jyTeTrlP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_EQ0kcMJt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TYtJaBQi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Iflo0g16_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hS7lyUnL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KjbYDFNH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FpmVps5e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_faW0Mxu8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fOY3gcIE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QnNAmdaE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_G22QdiET_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Ujgjf8Gl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dgexVbqi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yEy1CvuU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_c0KyIi6M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ULvsi50h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6YwvAd6h_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_eOgXnkcJ;
  SignalLine sLine_i34V4NBz;
  SignalLine sLine_p3r9zwH1;
  SignalLine sLine_nCaPxbZz;
  SignalLine sLine_nbcFF3HK;
  SignalBiquad sBiquad_s_yBHByhHg;
  SignalLine sLine_IgbiGREg;
  SignalLine sLine_PAVWumyt;
  SignalLine sLine_fLirYtYr;
  SignalLine sLine_uPIotyQx;
  SignalBiquad sBiquad_s_uCkT4eYv;
  SignalLine sLine_pFpRcWns;
  SignalLine sLine_Mx1SbvoR;
  SignalLine sLine_78Kyg53w;
  SignalLine sLine_CFGW14yJ;
  SignalLine sLine_s57KYiHu;
  SignalBiquad sBiquad_s_fSO6cUoF;
  SignalLine sLine_6dhMzCot;
  SignalLine sLine_2kqArO3G;
  SignalLine sLine_CdTBkT5S;
  SignalLine sLine_hiN9cr4n;
  SignalLine sLine_QlcXaDWA;
  SignalBiquad sBiquad_s_jLBjubCp;
  SignalLine sLine_vxW4LWll;
  SignalLine sLine_3wqv4dRv;
  SignalLine sLine_v597Oqam;
  SignalLine sLine_4SFwmirq;
  SignalBiquad sBiquad_s_pKumtdg6;
  SignalLine sLine_N1XWIGe2;
  SignalLine sLine_zGjelxwf;
  SignalLine sLine_7blWAaSD;
  SignalLine sLine_3uBq9Lvk;
  SignalLine sLine_i2fUtcKF;
  SignalBiquad sBiquad_s_y1c5Ra2w;
  ControlVar cVar_cUIezvV7;
  ControlVar cVar_1KsnFI01;
  ControlVar cVar_WQHKiwk2;
  ControlVar cVar_BtpvP7q4;
  ControlSlice cSlice_su84DMlq;
  ControlVar cVar_ys9jxgud;
  ControlVar cVar_MCKSVMn8;
  ControlIf cIf_gqalfvzm;
  ControlIf cIf_1vmsHIjc;
  ControlBinop cBinop_IC1UXyr0;
  ControlBinop cBinop_fNewvSeq;
  ControlBinop cBinop_r9iDcbiS;
  ControlBinop cBinop_QfgKSdpV;
  ControlBinop cBinop_pNIkAaYD;
  ControlIf cIf_vUnOqe6W;
  ControlBinop cBinop_0mxXSR57;
  ControlBinop cBinop_5vThTYXm;
  ControlBinop cBinop_sh6w7r3G;
  ControlBinop cBinop_pa2F2LGP;
  ControlBinop cBinop_ktLAkGoC;
  ControlVar cVar_wv6WW2Ba;
  ControlIf cIf_5Y7X95fP;
  ControlIf cIf_gsh5d0kx;
  ControlBinop cBinop_guV7kM13;
  ControlBinop cBinop_pESETsjm;
  ControlBinop cBinop_RjBxKNot;
  ControlBinop cBinop_cAD6AdxT;
  ControlBinop cBinop_0owhkTZ8;
  ControlIf cIf_OA4c9ns4;
  ControlBinop cBinop_yoUCjEgz;
  ControlBinop cBinop_gqPyqW5b;
  ControlBinop cBinop_HgPDuIzM;
  ControlBinop cBinop_Qa2ju6ha;
  ControlBinop cBinop_PnTHhwdA;
  ControlVar cVar_wTYeE4ON;
  ControlIf cIf_fAOBzcHZ;
  ControlIf cIf_K5V93tSI;
  ControlBinop cBinop_FQKq9A3v;
  ControlBinop cBinop_5aQSJABb;
  ControlBinop cBinop_HumcfLvD;
  ControlBinop cBinop_GpEoUOwZ;
  ControlBinop cBinop_GTAfUGac;
  ControlIf cIf_Jm6S79dN;
  ControlBinop cBinop_ADrdXS62;
  ControlBinop cBinop_cxfsmVXS;
  ControlBinop cBinop_XWuZZxpV;
  ControlBinop cBinop_J7JcQYRs;
  ControlBinop cBinop_zzR1svFB;
  ControlIf cIf_cTWn5Rf0;
  ControlSlice cSlice_ZifBwXq7;
  ControlVar cVar_aQbNrOb7;
  ControlSlice cSlice_yjtX40Wj;
  ControlVar cVar_wPC3SQ3v;
  ControlSlice cSlice_DrIAaLaX;
  ControlVar cVar_HJqxy73v;
  ControlSlice cSlice_tGUhK2fI;
  ControlVar cVar_Dk1QwCJb;
  ControlBinop cBinop_eLnqUE6n;
  ControlBinop cBinop_Esk3jCMv;
  ControlBinop cBinop_Jw97jJZi;
  ControlBinop cBinop_s32JO4co;
  ControlBinop cBinop_QLyVDBeL;
  ControlBinop cBinop_4mYbGFRV;
  ControlBinop cBinop_DovnQpKf;
  ControlBinop cBinop_I6AmYcpO;
  ControlVar cVar_qIoQPiiV;
  ControlBinop cBinop_QoN3I4Gh;
  ControlBinop cBinop_cLRYdOrh;
  ControlBinop cBinop_U7PDIwcV;
  ControlBinop cBinop_Y74yRI9V;
  ControlBinop cBinop_rxGeenlc;
  ControlBinop cBinop_8XswOpHC;
  ControlBinop cBinop_nmqFbhBi;
  ControlBinop cBinop_L2EsIKcO;
  ControlVar cVar_BOtuSODI;
  ControlVar cVar_464mNGuU;
  ControlBinop cBinop_pMphFYPa;
  ControlBinop cBinop_PmzaG30G;
  ControlBinop cBinop_9nvTHhaS;
  ControlBinop cBinop_ZZd7EVKw;
  ControlBinop cBinop_iKqaZ6rg;
  ControlBinop cBinop_EnsKT6vS;
  ControlBinop cBinop_TUpipfoH;
  ControlBinop cBinop_9rcXjZ7q;
  ControlBinop cBinop_juySaosg;
  ControlBinop cBinop_7mRvg9zg;
  ControlBinop cBinop_HZ6WGP83;
  ControlBinop cBinop_UanKq7LQ;
  ControlBinop cBinop_IHkhln1J;
  ControlBinop cBinop_19cQbgAU;
  ControlBinop cBinop_RobUIldw;
  ControlBinop cBinop_HMzMaesb;
  ControlBinop cBinop_n2KTiHZO;
  ControlBinop cBinop_lz4XMFQI;
  ControlBinop cBinop_QRx9ehEJ;
  ControlBinop cBinop_HHxlVDOm;
  ControlVar cVar_prYE9sax;
  ControlVar cVar_P1rhF2JN;
  ControlVar cVar_hrQY3Isx;
  ControlBinop cBinop_KSrHJjE2;
  ControlBinop cBinop_1WbacYbx;
  ControlBinop cBinop_bOjzm0A2;
  ControlBinop cBinop_NJ50hfOr;
  ControlBinop cBinop_W5AIKOVe;
  ControlBinop cBinop_rymBI8dZ;
  ControlBinop cBinop_P1KTxKVq;
  ControlBinop cBinop_GpwtMzf0;
  ControlBinop cBinop_gn7rnptX;
  ControlBinop cBinop_bOnhr2u4;
  ControlBinop cBinop_20hmtwIx;
  ControlBinop cBinop_i0OTMGo7;
  ControlBinop cBinop_N3hkwnI2;
  ControlBinop cBinop_YFc7iLeM;
  ControlBinop cBinop_WRDjO9pT;
  ControlBinop cBinop_MQk5gk0N;
  ControlBinop cBinop_60wyzdgF;
  ControlBinop cBinop_3lZujtZ4;
  ControlBinop cBinop_wY03nKLj;
  ControlBinop cBinop_0iIex6HI;
  ControlBinop cBinop_lLj5ZqZR;
  ControlBinop cBinop_JtUdBxM5;
  ControlBinop cBinop_r5wI7XCm;
  ControlVar cVar_RfZ2Jw2K;
  ControlVar cVar_LgFwJY1R;
  ControlVar cVar_ChSRPxOL;
  ControlBinop cBinop_UAY4ojDX;
  ControlBinop cBinop_yNFEHRGz;
  ControlBinop cBinop_1kWz4vXY;
  ControlBinop cBinop_kNnqC38d;
  ControlBinop cBinop_yEJwWGEu;
  ControlBinop cBinop_b0q2fhxl;
  ControlBinop cBinop_hir7HkhG;
  ControlBinop cBinop_F1vEUmri;
  ControlBinop cBinop_dhg8ly94;
  ControlBinop cBinop_R0LKoVkt;
  ControlBinop cBinop_jQ0hiYBh;
  ControlBinop cBinop_Esi1aqXx;
  SignalVarf sVarf_q6SzdLM0;
  SignalVarf sVarf_gaFxM8l2;
  SignalVarf sVarf_lBlvx7Cw;
  ControlSlice cSlice_gU19ehjC;
  ControlVar cVar_DTiWvcJg;
  ControlVar cVar_c3DQ87W7;
  ControlIf cIf_hCNHsc4Y;
  ControlIf cIf_fYTQpExb;
  ControlBinop cBinop_k2pRw2ss;
  ControlBinop cBinop_ZQwvMaiE;
  ControlBinop cBinop_O2B1lfEY;
  ControlBinop cBinop_qv0tD9CO;
  ControlBinop cBinop_yufqshcc;
  ControlIf cIf_b3cgc7lB;
  ControlBinop cBinop_cO6BiIjA;
  ControlBinop cBinop_iemllIsl;
  ControlBinop cBinop_X8aKVUiU;
  ControlBinop cBinop_4UnkZUXM;
  ControlBinop cBinop_nV0Bk824;
  ControlVar cVar_tMZqMRlO;
  ControlIf cIf_45yHOFK2;
  ControlIf cIf_INjT0dDO;
  ControlBinop cBinop_SgDDUBVf;
  ControlBinop cBinop_HpPRGxJ6;
  ControlBinop cBinop_knsOEo4g;
  ControlBinop cBinop_5nev20IX;
  ControlBinop cBinop_rG3V957N;
  ControlIf cIf_dk4sexAs;
  ControlBinop cBinop_ZABYhuTQ;
  ControlBinop cBinop_uS9jeZJv;
  ControlBinop cBinop_iawutD4j;
  ControlBinop cBinop_MpNWhf0f;
  ControlBinop cBinop_v5nBibl0;
  ControlVar cVar_6zfdBu88;
  ControlIf cIf_0k9k1H8D;
  ControlIf cIf_YqySUZwF;
  ControlBinop cBinop_k2bIUYaN;
  ControlBinop cBinop_GFo88sso;
  ControlBinop cBinop_Z4E9hFsz;
  ControlBinop cBinop_o1BTglSC;
  ControlBinop cBinop_gMWwBes6;
  ControlIf cIf_3Bo5Nkap;
  ControlBinop cBinop_Oa0ba5LP;
  ControlBinop cBinop_Y7ivzLOc;
  ControlBinop cBinop_GGhjsGeY;
  ControlBinop cBinop_d2DLzwQX;
  ControlBinop cBinop_yNq27SeB;
  ControlIf cIf_iignx3Gg;
  ControlSlice cSlice_euSTgymp;
  ControlVar cVar_iiVmBfzb;
  ControlSlice cSlice_DjVp4722;
  ControlVar cVar_Z5TXTVex;
  ControlSlice cSlice_vB9qB3MX;
  ControlVar cVar_QxKBERj8;
  ControlSlice cSlice_2GFeHoo5;
  ControlVar cVar_1njI2lqr;
  ControlBinop cBinop_2V0Y4izh;
  ControlBinop cBinop_nTZb6w6m;
  ControlBinop cBinop_nkEvDhve;
  ControlBinop cBinop_nl2oC9ag;
  ControlBinop cBinop_3e8A0lWo;
  ControlBinop cBinop_vnNIkDfL;
  ControlBinop cBinop_GQi2vcoB;
  ControlBinop cBinop_0bod6czK;
  ControlVar cVar_5ACX61E6;
  ControlBinop cBinop_YhAFoJ8R;
  ControlBinop cBinop_1O8QgD3C;
  ControlBinop cBinop_AEbxkFJr;
  ControlBinop cBinop_3xT5FRPD;
  ControlBinop cBinop_KRRw9Siz;
  ControlBinop cBinop_7v9BoCON;
  ControlBinop cBinop_wqRD8vch;
  ControlBinop cBinop_aI1vPQ4u;
  ControlVar cVar_y3ecMgaN;
  ControlVar cVar_oYrD3ALX;
  ControlBinop cBinop_6YjzVdCI;
  ControlBinop cBinop_eG7dhB9H;
  ControlBinop cBinop_R0OL8f3d;
  ControlBinop cBinop_ytQMTBph;
  ControlBinop cBinop_N5Hf2p4S;
  ControlBinop cBinop_h8wccjne;
  ControlBinop cBinop_lf7dty8f;
  ControlBinop cBinop_2VfysnYM;
  ControlBinop cBinop_UgrPaUeK;
  ControlBinop cBinop_vEjo5Tbv;
  ControlBinop cBinop_GB3dlVKl;
  ControlBinop cBinop_Cdh2ip34;
  ControlBinop cBinop_yNSPjVVe;
  ControlBinop cBinop_ID6kjKXr;
  ControlBinop cBinop_NRUalJev;
  ControlBinop cBinop_PigsOIwM;
  ControlBinop cBinop_kSNLvh0P;
  ControlBinop cBinop_8l6wrzCA;
  ControlBinop cBinop_kQI6oaTr;
  ControlBinop cBinop_U7OzZipx;
  ControlVar cVar_SfehNY3I;
  ControlVar cVar_Y8tpfoPB;
  ControlVar cVar_mp9kLysR;
  ControlBinop cBinop_JpGodCbq;
  ControlBinop cBinop_StXLiDVi;
  ControlBinop cBinop_wLDlEmbU;
  ControlBinop cBinop_wRVN1jrQ;
  ControlBinop cBinop_VbtUE1Ar;
  ControlBinop cBinop_Z26JEh1R;
  ControlBinop cBinop_IOBaI3JB;
  ControlBinop cBinop_3WqD4raG;
  ControlBinop cBinop_lcYujyJz;
  ControlBinop cBinop_R3gvYVON;
  ControlBinop cBinop_CJzBlbU5;
  ControlBinop cBinop_E4Dt1efc;
  ControlBinop cBinop_rcFiL0lz;
  ControlBinop cBinop_duGy0c6k;
  ControlBinop cBinop_k1NqZPPL;
  ControlBinop cBinop_KWXyH6Tc;
  ControlBinop cBinop_aXgzUYht;
  ControlBinop cBinop_gTY41RCS;
  ControlBinop cBinop_qDCzAWWZ;
  ControlBinop cBinop_iSqZhIQ6;
  ControlBinop cBinop_gHDOIcbc;
  ControlBinop cBinop_zmBOPysX;
  ControlBinop cBinop_AcwGRtI5;
  ControlVar cVar_d0StjQ6J;
  ControlVar cVar_ZnpTNV6M;
  ControlVar cVar_yiGAIYEK;
  ControlBinop cBinop_FrqXzy8i;
  ControlBinop cBinop_DaCJ8Tjp;
  ControlBinop cBinop_ReS3Uqtm;
  ControlBinop cBinop_0Vb6saVT;
  ControlBinop cBinop_NUbewmt5;
  ControlBinop cBinop_OrB35BRi;
  ControlBinop cBinop_2Awvtwpk;
  ControlBinop cBinop_deSQi2J1;
  ControlBinop cBinop_sA4DfsYE;
  ControlBinop cBinop_ejIxRizH;
  ControlBinop cBinop_dOqUznjH;
  ControlBinop cBinop_4NtxR0j5;
  SignalVarf sVarf_nOaH63ok;
  SignalVarf sVarf_P2Xl2VQ6;
  SignalVarf sVarf_wN6yYYsg;
  ControlVar cVar_lHY20qsq;
  ControlVar cVar_GiSrLIRP;
  ControlBinop cBinop_kPJmP7TO;
  ControlBinop cBinop_27crII6x;
  ControlBinop cBinop_eqpY4BBU;
  ControlBinop cBinop_C79w3AQf;
  ControlBinop cBinop_ktULEVFv;
  ControlBinop cBinop_yKbzyjDc;
  ControlBinop cBinop_xQTQjlyv;
};

#endif // _HEAVY_CONTEXT_WSTD_3Q_HPP_
