/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_3Q.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_3Q *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_3Q_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_3Q();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_3Q::Heavy_WSTD_3Q(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_eOgXnkcJ);
  numBytes += sLine_init(&sLine_i34V4NBz);
  numBytes += sLine_init(&sLine_p3r9zwH1);
  numBytes += sLine_init(&sLine_nCaPxbZz);
  numBytes += sLine_init(&sLine_nbcFF3HK);
  numBytes += sBiquad_init(&sBiquad_s_yBHByhHg);
  numBytes += sLine_init(&sLine_IgbiGREg);
  numBytes += sLine_init(&sLine_PAVWumyt);
  numBytes += sLine_init(&sLine_fLirYtYr);
  numBytes += sLine_init(&sLine_uPIotyQx);
  numBytes += sBiquad_init(&sBiquad_s_uCkT4eYv);
  numBytes += sLine_init(&sLine_pFpRcWns);
  numBytes += sLine_init(&sLine_Mx1SbvoR);
  numBytes += sLine_init(&sLine_78Kyg53w);
  numBytes += sLine_init(&sLine_CFGW14yJ);
  numBytes += sLine_init(&sLine_s57KYiHu);
  numBytes += sBiquad_init(&sBiquad_s_fSO6cUoF);
  numBytes += sLine_init(&sLine_6dhMzCot);
  numBytes += sLine_init(&sLine_2kqArO3G);
  numBytes += sLine_init(&sLine_CdTBkT5S);
  numBytes += sLine_init(&sLine_hiN9cr4n);
  numBytes += sLine_init(&sLine_QlcXaDWA);
  numBytes += sBiquad_init(&sBiquad_s_jLBjubCp);
  numBytes += sLine_init(&sLine_vxW4LWll);
  numBytes += sLine_init(&sLine_3wqv4dRv);
  numBytes += sLine_init(&sLine_v597Oqam);
  numBytes += sLine_init(&sLine_4SFwmirq);
  numBytes += sBiquad_init(&sBiquad_s_pKumtdg6);
  numBytes += sLine_init(&sLine_N1XWIGe2);
  numBytes += sLine_init(&sLine_zGjelxwf);
  numBytes += sLine_init(&sLine_7blWAaSD);
  numBytes += sLine_init(&sLine_3uBq9Lvk);
  numBytes += sLine_init(&sLine_i2fUtcKF);
  numBytes += sBiquad_init(&sBiquad_s_y1c5Ra2w);
  numBytes += cVar_init_f(&cVar_cUIezvV7, 0.0f);
  numBytes += cVar_init_f(&cVar_1KsnFI01, 0.0f);
  numBytes += cVar_init_f(&cVar_WQHKiwk2, 0.0f);
  numBytes += cVar_init_f(&cVar_BtpvP7q4, 0.0f);
  numBytes += cSlice_init(&cSlice_su84DMlq, 1, -1);
  numBytes += cVar_init_f(&cVar_ys9jxgud, 1337.0f);
  numBytes += cVar_init_f(&cVar_MCKSVMn8, 0.0f);
  numBytes += cIf_init(&cIf_gqalfvzm, false);
  numBytes += cIf_init(&cIf_1vmsHIjc, false);
  numBytes += cBinop_init(&cBinop_IC1UXyr0, 0.0f); // __pow
  numBytes += cIf_init(&cIf_vUnOqe6W, false);
  numBytes += cBinop_init(&cBinop_sh6w7r3G, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_pa2F2LGP, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_ktLAkGoC, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_wv6WW2Ba, 0.0f);
  numBytes += cIf_init(&cIf_5Y7X95fP, false);
  numBytes += cIf_init(&cIf_gsh5d0kx, false);
  numBytes += cBinop_init(&cBinop_guV7kM13, 0.0f); // __pow
  numBytes += cIf_init(&cIf_OA4c9ns4, false);
  numBytes += cBinop_init(&cBinop_HgPDuIzM, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Qa2ju6ha, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_PnTHhwdA, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_wTYeE4ON, 0.0f);
  numBytes += cIf_init(&cIf_fAOBzcHZ, false);
  numBytes += cIf_init(&cIf_K5V93tSI, false);
  numBytes += cBinop_init(&cBinop_FQKq9A3v, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Jm6S79dN, false);
  numBytes += cBinop_init(&cBinop_XWuZZxpV, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_J7JcQYRs, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_zzR1svFB, -15.0f); // __eq
  numBytes += cIf_init(&cIf_cTWn5Rf0, false);
  numBytes += cSlice_init(&cSlice_ZifBwXq7, 1, -1);
  numBytes += cVar_init_f(&cVar_aQbNrOb7, 0.0f);
  numBytes += cSlice_init(&cSlice_yjtX40Wj, 1, -1);
  numBytes += cVar_init_f(&cVar_wPC3SQ3v, 0.0f);
  numBytes += cSlice_init(&cSlice_DrIAaLaX, 1, -1);
  numBytes += cVar_init_f(&cVar_HJqxy73v, 0.0f);
  numBytes += cSlice_init(&cSlice_tGUhK2fI, 1, -1);
  numBytes += cVar_init_f(&cVar_Dk1QwCJb, 0.313f);
  numBytes += cBinop_init(&cBinop_Esk3jCMv, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Jw97jJZi, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_qIoQPiiV, 0.0f);
  numBytes += cVar_init_f(&cVar_BOtuSODI, 1337.0f);
  numBytes += cVar_init_f(&cVar_464mNGuU, 0.3f);
  numBytes += cBinop_init(&cBinop_PmzaG30G, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iKqaZ6rg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_EnsKT6vS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TUpipfoH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9rcXjZ7q, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_juySaosg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HZ6WGP83, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_UanKq7LQ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_prYE9sax, 0.0f);
  numBytes += cVar_init_f(&cVar_P1rhF2JN, 1337.0f);
  numBytes += cVar_init_f(&cVar_hrQY3Isx, 0.313f);
  numBytes += cBinop_init(&cBinop_1WbacYbx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_W5AIKOVe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rymBI8dZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_P1KTxKVq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GpwtMzf0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bOnhr2u4, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_20hmtwIx, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_RfZ2Jw2K, 0.0f);
  numBytes += cVar_init_f(&cVar_LgFwJY1R, 1037.0f);
  numBytes += cVar_init_f(&cVar_ChSRPxOL, 0.4f);
  numBytes += cBinop_init(&cBinop_yNFEHRGz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yEJwWGEu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_b0q2fhxl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hir7HkhG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_F1vEUmri, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dhg8ly94, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_q6SzdLM0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gaFxM8l2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lBlvx7Cw, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_gU19ehjC, 1, -1);
  numBytes += cVar_init_f(&cVar_DTiWvcJg, 1337.0f);
  numBytes += cVar_init_f(&cVar_c3DQ87W7, 0.0f);
  numBytes += cIf_init(&cIf_hCNHsc4Y, false);
  numBytes += cIf_init(&cIf_fYTQpExb, false);
  numBytes += cBinop_init(&cBinop_k2pRw2ss, 0.0f); // __pow
  numBytes += cIf_init(&cIf_b3cgc7lB, false);
  numBytes += cBinop_init(&cBinop_X8aKVUiU, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_4UnkZUXM, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_nV0Bk824, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_tMZqMRlO, 0.0f);
  numBytes += cIf_init(&cIf_45yHOFK2, false);
  numBytes += cIf_init(&cIf_INjT0dDO, false);
  numBytes += cBinop_init(&cBinop_SgDDUBVf, 0.0f); // __pow
  numBytes += cIf_init(&cIf_dk4sexAs, false);
  numBytes += cBinop_init(&cBinop_iawutD4j, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_MpNWhf0f, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_v5nBibl0, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_6zfdBu88, 0.0f);
  numBytes += cIf_init(&cIf_0k9k1H8D, false);
  numBytes += cIf_init(&cIf_YqySUZwF, false);
  numBytes += cBinop_init(&cBinop_k2bIUYaN, 0.0f); // __pow
  numBytes += cIf_init(&cIf_3Bo5Nkap, false);
  numBytes += cBinop_init(&cBinop_GGhjsGeY, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_d2DLzwQX, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_yNq27SeB, -15.0f); // __eq
  numBytes += cIf_init(&cIf_iignx3Gg, false);
  numBytes += cSlice_init(&cSlice_euSTgymp, 1, -1);
  numBytes += cVar_init_f(&cVar_iiVmBfzb, 0.0f);
  numBytes += cSlice_init(&cSlice_DjVp4722, 1, -1);
  numBytes += cVar_init_f(&cVar_Z5TXTVex, 0.0f);
  numBytes += cSlice_init(&cSlice_vB9qB3MX, 1, -1);
  numBytes += cVar_init_f(&cVar_QxKBERj8, 0.0f);
  numBytes += cSlice_init(&cSlice_2GFeHoo5, 1, -1);
  numBytes += cVar_init_f(&cVar_1njI2lqr, 0.313f);
  numBytes += cBinop_init(&cBinop_nTZb6w6m, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_nkEvDhve, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_5ACX61E6, 0.0f);
  numBytes += cVar_init_f(&cVar_y3ecMgaN, 1337.0f);
  numBytes += cVar_init_f(&cVar_oYrD3ALX, 0.3f);
  numBytes += cBinop_init(&cBinop_eG7dhB9H, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_N5Hf2p4S, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_h8wccjne, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lf7dty8f, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2VfysnYM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UgrPaUeK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GB3dlVKl, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Cdh2ip34, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_SfehNY3I, 0.0f);
  numBytes += cVar_init_f(&cVar_Y8tpfoPB, 1337.0f);
  numBytes += cVar_init_f(&cVar_mp9kLysR, 0.313f);
  numBytes += cBinop_init(&cBinop_StXLiDVi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_VbtUE1Ar, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Z26JEh1R, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IOBaI3JB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3WqD4raG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_R3gvYVON, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_CJzBlbU5, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_d0StjQ6J, 0.0f);
  numBytes += cVar_init_f(&cVar_ZnpTNV6M, 1037.0f);
  numBytes += cVar_init_f(&cVar_yiGAIYEK, 0.4f);
  numBytes += cBinop_init(&cBinop_DaCJ8Tjp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NUbewmt5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OrB35BRi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2Awvtwpk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_deSQi2J1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sA4DfsYE, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_nOaH63ok, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_P2Xl2VQ6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wN6yYYsg, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_lHY20qsq, 5705.6f);
  numBytes += cVar_init_f(&cVar_GiSrLIRP, 313.3f);
  numBytes += cBinop_init(&cBinop_kPJmP7TO, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_27crII6x, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_eqpY4BBU, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_3Q::~Heavy_WSTD_3Q() {
  // nothing to free
}

HvTable *Heavy_WSTD_3Q::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_3Q::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3Gugb2qn_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nmMEGfHY_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aQ19JBQO_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6YwvAd6h_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_F3RHDmo6_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5sKY9880_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7i0kAQyB_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PiS0RvqL_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0whNdDET_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_20vKAKem_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bCAlAxRZ_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vtc5bGpE_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3mo4gYW3_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YyvDhqZy_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8eZXjP9Y_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EQ0kcMJt_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jyTeTrlP_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SYfO7hc8_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hS7lyUnL_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KjbYDFNH_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TYtJaBQi_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Iflo0g16_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FpmVps5e_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QnNAmdaE_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fOY3gcIE_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_faW0Mxu8_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dgexVbqi_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ujgjf8Gl_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_G22QdiET_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ULvsi50h_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_c0KyIi6M_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yEy1CvuU_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YGyxY8kz_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_3Q::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_3Q::cVar_cUIezvV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LeGb8oHJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_1KsnFI01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sFxVbo4X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_WQHKiwk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UHD1d5GE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_BtpvP7q4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VbDfmBy7_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pOnm00Gs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_07PqmlgE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L1DlRq50_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_xT1D8SZG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_su84DMlq, 0, m, &cSlice_su84DMlq_sendMessage);
      break;
    }
    default: {
      cSwitchcase_wKtzHOkL_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_su84DMlq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4hiwsXco_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4hiwsXco_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_ys9jxgud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4hiwsXco_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_4hiwsXco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7i0kAQyB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_MCKSVMn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0mxXSR57_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_gqalfvzm, 0, m, &cIf_gqalfvzm_sendMessage);
}

void Heavy_WSTD_3Q::cIf_gqalfvzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_5vThTYXm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_1vmsHIjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_AS1a7e0D_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_QfgKSdpV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_DJ1An2ns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IC1UXyr0, HV_BINOP_POW, 0, m, &cBinop_IC1UXyr0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IC1UXyr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vUnOqe6W, 0, m, &cIf_vUnOqe6W_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fNewvSeq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_pNIkAaYD_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HYmrJZ9y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1vmsHIjc, 0, m, &cIf_1vmsHIjc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1KH3sBKP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_r9iDcbiS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_r9iDcbiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1vmsHIjc, 1, m, &cIf_1vmsHIjc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QfgKSdpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_fNewvSeq_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_AS1a7e0D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_vUnOqe6W, 0, m, &cIf_vUnOqe6W_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pNIkAaYD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IC1UXyr0, HV_BINOP_POW, 1, m, &cBinop_IC1UXyr0_sendMessage);
  cMsg_DJ1An2ns_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_vUnOqe6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_q6SzdLM0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_0mxXSR57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gqalfvzm, 1, m, &cIf_gqalfvzm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5vThTYXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pa2F2LGP, HV_BINOP_GREATER_THAN, 1, m, &cBinop_pa2F2LGP_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ktLAkGoC, HV_BINOP_EQ, 1, m, &cBinop_ktLAkGoC_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_fZrD4Uow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_sh6w7r3G, HV_BINOP_ADD, 0, m, &cBinop_sh6w7r3G_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_sh6w7r3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1KH3sBKP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HYmrJZ9y_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pa2F2LGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vUnOqe6W, 1, m, &cIf_vUnOqe6W_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ktLAkGoC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2BQz9asi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_2BQz9asi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_q6SzdLM0, m);
}

void Heavy_WSTD_3Q::cCast_KD7ppAwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sh6w7r3G, HV_BINOP_ADD, 1, m, &cBinop_sh6w7r3G_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pa2F2LGP, HV_BINOP_GREATER_THAN, 0, m, &cBinop_pa2F2LGP_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ktLAkGoC, HV_BINOP_EQ, 0, m, &cBinop_ktLAkGoC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_YzP0nOpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MCKSVMn8, 0, m, &cVar_MCKSVMn8_sendMessage);
}

void Heavy_WSTD_3Q::cCast_QRCidf0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fZrD4Uow_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_wv6WW2Ba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_yoUCjEgz_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_5Y7X95fP, 0, m, &cIf_5Y7X95fP_sendMessage);
}

void Heavy_WSTD_3Q::cIf_5Y7X95fP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_gqPyqW5b_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_gsh5d0kx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_rLArErhy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_cAD6AdxT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_zlb9OmFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_guV7kM13, HV_BINOP_POW, 0, m, &cBinop_guV7kM13_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_guV7kM13_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OA4c9ns4, 0, m, &cIf_OA4c9ns4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pESETsjm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_0owhkTZ8_sendMessage);
}

void Heavy_WSTD_3Q::cCast_H8ion10T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gsh5d0kx, 0, m, &cIf_gsh5d0kx_sendMessage);
}

void Heavy_WSTD_3Q::cCast_dE8zqpvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_RjBxKNot_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RjBxKNot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gsh5d0kx, 1, m, &cIf_gsh5d0kx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cAD6AdxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_pESETsjm_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_rLArErhy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_OA4c9ns4, 0, m, &cIf_OA4c9ns4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0owhkTZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_guV7kM13, HV_BINOP_POW, 1, m, &cBinop_guV7kM13_sendMessage);
  cMsg_zlb9OmFF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_OA4c9ns4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_R0LKoVkt_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jQ0hiYBh_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Esi1aqXx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_yoUCjEgz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5Y7X95fP, 1, m, &cIf_5Y7X95fP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gqPyqW5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qa2ju6ha, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Qa2ju6ha_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PnTHhwdA, HV_BINOP_EQ, 1, m, &cBinop_PnTHhwdA_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_nvahWdhB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HgPDuIzM, HV_BINOP_ADD, 0, m, &cBinop_HgPDuIzM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HgPDuIzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dE8zqpvG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H8ion10T_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Qa2ju6ha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OA4c9ns4, 1, m, &cIf_OA4c9ns4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PnTHhwdA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iH4jKjxq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_iH4jKjxq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_R0LKoVkt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jQ0hiYBh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Esi1aqXx_sendMessage);
}

void Heavy_WSTD_3Q::cCast_A3P5cuRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wv6WW2Ba, 0, m, &cVar_wv6WW2Ba_sendMessage);
}

void Heavy_WSTD_3Q::cCast_PEYBubvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nvahWdhB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_yZkPyEzb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HgPDuIzM, HV_BINOP_ADD, 1, m, &cBinop_HgPDuIzM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qa2ju6ha, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Qa2ju6ha_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PnTHhwdA, HV_BINOP_EQ, 0, m, &cBinop_PnTHhwdA_sendMessage);
}

void Heavy_WSTD_3Q::cVar_wTYeE4ON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ADrdXS62_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_fAOBzcHZ, 0, m, &cIf_fAOBzcHZ_sendMessage);
}

void Heavy_WSTD_3Q::cIf_fAOBzcHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_cxfsmVXS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_K5V93tSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_AwXNXIIP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_GpEoUOwZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_HRthIZmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FQKq9A3v, HV_BINOP_POW, 0, m, &cBinop_FQKq9A3v_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FQKq9A3v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Jm6S79dN, 0, m, &cIf_Jm6S79dN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5aQSJABb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_GTAfUGac_sendMessage);
}

void Heavy_WSTD_3Q::cCast_BVq9lgd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K5V93tSI, 0, m, &cIf_K5V93tSI_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Oo3NDynE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_HumcfLvD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HumcfLvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K5V93tSI, 1, m, &cIf_K5V93tSI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GpEoUOwZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_5aQSJABb_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_AwXNXIIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Jm6S79dN, 0, m, &cIf_Jm6S79dN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GTAfUGac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FQKq9A3v, HV_BINOP_POW, 1, m, &cBinop_FQKq9A3v_sendMessage);
  cMsg_HRthIZmF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_Jm6S79dN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_lBlvx7Cw, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_ADrdXS62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fAOBzcHZ, 1, m, &cIf_fAOBzcHZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cxfsmVXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J7JcQYRs, HV_BINOP_GREATER_THAN, 1, m, &cBinop_J7JcQYRs_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zzR1svFB, HV_BINOP_EQ, 1, m, &cBinop_zzR1svFB_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_6XnKkZ3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XWuZZxpV, HV_BINOP_ADD, 0, m, &cBinop_XWuZZxpV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XWuZZxpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Oo3NDynE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BVq9lgd9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_J7JcQYRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Jm6S79dN, 1, m, &cIf_Jm6S79dN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zzR1svFB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IHYASNtE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_IHYASNtE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_lBlvx7Cw, m);
}

void Heavy_WSTD_3Q::cCast_WdREiXMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wTYeE4ON, 0, m, &cVar_wTYeE4ON_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ByGDPRDF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6XnKkZ3z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_rvCBLlo1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XWuZZxpV, HV_BINOP_ADD, 1, m, &cBinop_XWuZZxpV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_J7JcQYRs, HV_BINOP_GREATER_THAN, 0, m, &cBinop_J7JcQYRs_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zzR1svFB, HV_BINOP_EQ, 0, m, &cBinop_zzR1svFB_sendMessage);
}

void Heavy_WSTD_3Q::cIf_cTWn5Rf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_gaFxM8l2, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_hM9chQTo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ZifBwXq7, 0, m, &cSlice_ZifBwXq7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_w2OGn7g4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_ZifBwXq7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_AH8ww4dt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_AH8ww4dt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_aQbNrOb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AH8ww4dt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_AH8ww4dt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_F3RHDmo6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_w2OGn7g4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yjtX40Wj, 0, m, &cSlice_yjtX40Wj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_xT1D8SZG_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_yjtX40Wj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Z12gzwTn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Z12gzwTn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_wPC3SQ3v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Z12gzwTn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Z12gzwTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0whNdDET_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_wKtzHOkL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DrIAaLaX, 0, m, &cSlice_DrIAaLaX_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Zn1Hq1Tt_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_DrIAaLaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2TkkBKkw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2TkkBKkw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_HJqxy73v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2TkkBKkw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_2TkkBKkw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5sKY9880_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_Zn1Hq1Tt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tGUhK2fI, 0, m, &cSlice_tGUhK2fI_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_tGUhK2fI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_prxoUPt1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_prxoUPt1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_Dk1QwCJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_prxoUPt1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_prxoUPt1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PiS0RvqL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_TPDeRizz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eOgXnkcJ, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_C7My8acg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_i34V4NBz, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_27xl0zya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_p3r9zwH1, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_xYuHaQ2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nCaPxbZz, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_7jWMNzLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nbcFF3HK, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_7zut5CtL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_eM0Q8CF3_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_eM0Q8CF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Esk3jCMv, HV_BINOP_DIVIDE, 1, m, &cBinop_Esk3jCMv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mmvNfIAS_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_DumALJSy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_eLnqUE6n_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Kx9iCuLK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_DumALJSy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eLnqUE6n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Esk3jCMv, HV_BINOP_DIVIDE, 0, m, &cBinop_Esk3jCMv_sendMessage);
}

void Heavy_WSTD_3Q::cCast_mmvNfIAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Kx9iCuLK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Esk3jCMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jw97jJZi, HV_BINOP_MULTIPLY, 1, m, &cBinop_Jw97jJZi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Jw97jJZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p3XWQcvO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T3BP61Ft_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_qukwexwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_X0LQGgNT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_5VzVnm7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YeVqT5nE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_s32JO4co_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_QLyVDBeL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QLyVDBeL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jw97jJZi, HV_BINOP_MULTIPLY, 0, m, &cBinop_Jw97jJZi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4mYbGFRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_DovnQpKf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DovnQpKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D6SOHsoq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_I6AmYcpO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qIoQPiiV, 1, m, &cVar_qIoQPiiV_sendMessage);
}

void Heavy_WSTD_3Q::cVar_qIoQPiiV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HdAQRsLW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_QoN3I4Gh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iKqaZ6rg, HV_BINOP_MULTIPLY, 1, m, &cBinop_iKqaZ6rg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cLRYdOrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QoN3I4Gh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_U7PDIwcV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Y74yRI9V_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Y74yRI9V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EnsKT6vS, HV_BINOP_MULTIPLY, 1, m, &cBinop_EnsKT6vS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rxGeenlc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TUpipfoH, HV_BINOP_MULTIPLY, 1, m, &cBinop_TUpipfoH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8XswOpHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rxGeenlc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nmqFbhBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9rcXjZ7q, HV_BINOP_MULTIPLY, 1, m, &cBinop_9rcXjZ7q_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Vdzu6LQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_L2EsIKcO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_L2EsIKcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_juySaosg, HV_BINOP_MULTIPLY, 1, m, &cBinop_juySaosg_sendMessage);
}

void Heavy_WSTD_3Q::cVar_BOtuSODI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HcQVQoqM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_s32JO4co_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kuCRIe6D_sendMessage);
}

void Heavy_WSTD_3Q::cVar_464mNGuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_4mYbGFRV_sendMessage);
}

void Heavy_WSTD_3Q::cCast_T3BP61Ft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_5VzVnm7L_sendMessage);
}

void Heavy_WSTD_3Q::cCast_p3XWQcvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_qukwexwU_sendMessage);
}

void Heavy_WSTD_3Q::cSend_X0LQGgNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vtc5bGpE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_YeVqT5nE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bCAlAxRZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_G1UZuG29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_20vKAKem_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_D6SOHsoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_pMphFYPa_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pMphFYPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PmzaG30G, HV_BINOP_MULTIPLY, 1, m, &cBinop_PmzaG30G_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PmzaG30G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9nvTHhaS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9nvTHhaS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_G1UZuG29_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_HdAQRsLW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZZd7EVKw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZZd7EVKw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U2Uvu5Pc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4nGyKwOc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TopRBoiT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Rl1abV2Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RM2b5Csx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IYBoBWH2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iKqaZ6rg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TPDeRizz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_EnsKT6vS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C7My8acg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_TUpipfoH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_27xl0zya_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_9rcXjZ7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xYuHaQ2N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_juySaosg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7jWMNzLP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_TGgowmBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_464mNGuU, 1, m, &cVar_464mNGuU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_JSWJQx9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BOtuSODI, 0, m, &cVar_BOtuSODI_sendMessage);
}

void Heavy_WSTD_3Q::cCast_RM2b5Csx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EnsKT6vS, HV_BINOP_MULTIPLY, 0, m, &cBinop_EnsKT6vS_sendMessage);
}

void Heavy_WSTD_3Q::cCast_4nGyKwOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_juySaosg, HV_BINOP_MULTIPLY, 0, m, &cBinop_juySaosg_sendMessage);
}

void Heavy_WSTD_3Q::cCast_U2Uvu5Pc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_TopRBoiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9rcXjZ7q, HV_BINOP_MULTIPLY, 0, m, &cBinop_9rcXjZ7q_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Rl1abV2Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TUpipfoH, HV_BINOP_MULTIPLY, 0, m, &cBinop_TUpipfoH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_IYBoBWH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iKqaZ6rg, HV_BINOP_MULTIPLY, 0, m, &cBinop_iKqaZ6rg_sendMessage);
}

void Heavy_WSTD_3Q::cCast_kuCRIe6D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qIoQPiiV, 0, m, &cVar_qIoQPiiV_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HcQVQoqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_464mNGuU, 0, m, &cVar_464mNGuU_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_NfK3mxXU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IgbiGREg, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_hHA6dHTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PAVWumyt, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_ZprILThN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fLirYtYr, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_FUVCIcAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uPIotyQx, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_zlUwS56B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3od8UrZx_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_3od8UrZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HZ6WGP83, HV_BINOP_DIVIDE, 1, m, &cBinop_HZ6WGP83_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2oSW4uRc_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_S16TQTuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_7mRvg9zg_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_PqSpCjpd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_S16TQTuL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7mRvg9zg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HZ6WGP83, HV_BINOP_DIVIDE, 0, m, &cBinop_HZ6WGP83_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2oSW4uRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PqSpCjpd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_HZ6WGP83_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UanKq7LQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_UanKq7LQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UanKq7LQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1EywBcGC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_17gCQywv_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_t16fJlki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fBu2ugb0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_TNr0ZvAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UbEE5F4e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_IHkhln1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_19cQbgAU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_19cQbgAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UanKq7LQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_UanKq7LQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RobUIldw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_HMzMaesb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HMzMaesb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KCMsDIct_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_n2KTiHZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rymBI8dZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_rymBI8dZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lz4XMFQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_prYE9sax, 1, m, &cVar_prYE9sax_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QRx9ehEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P1KTxKVq, HV_BINOP_MULTIPLY, 1, m, &cBinop_P1KTxKVq_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_fU7Q9J1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HHxlVDOm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HHxlVDOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GpwtMzf0, HV_BINOP_MULTIPLY, 1, m, &cBinop_GpwtMzf0_sendMessage);
}

void Heavy_WSTD_3Q::cVar_prYE9sax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PFPDA1r5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_P1rhF2JN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tmS7Hb3P_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_IHkhln1J_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1bI8iswt_sendMessage);
}

void Heavy_WSTD_3Q::cVar_hrQY3Isx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_RobUIldw_sendMessage);
}

void Heavy_WSTD_3Q::cCast_17gCQywv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_TNr0ZvAO_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1EywBcGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_t16fJlki_sendMessage);
}

void Heavy_WSTD_3Q::cSend_fBu2ugb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8eZXjP9Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_UbEE5F4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YyvDhqZy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_S3v8KCAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3mo4gYW3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_KCMsDIct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_KSrHJjE2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KSrHJjE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1WbacYbx, HV_BINOP_MULTIPLY, 1, m, &cBinop_1WbacYbx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1WbacYbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_bOjzm0A2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bOjzm0A2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_S3v8KCAD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_PFPDA1r5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_NJ50hfOr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NJ50hfOr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Qufgb4wd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dnrRv1jA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ikDmfXZi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lc0g5yQb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_W5AIKOVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NfK3mxXU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_rymBI8dZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hHA6dHTf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_P1KTxKVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZprILThN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_GpwtMzf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FUVCIcAC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_P9swUKS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_P1rhF2JN, 0, m, &cVar_P1rhF2JN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_dYGyM5r7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hrQY3Isx, 1, m, &cVar_hrQY3Isx_sendMessage);
}

void Heavy_WSTD_3Q::cCast_tmS7Hb3P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hrQY3Isx, 0, m, &cVar_hrQY3Isx_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1bI8iswt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_prYE9sax, 0, m, &cVar_prYE9sax_sendMessage);
}

void Heavy_WSTD_3Q::cCast_lc0g5yQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W5AIKOVe, HV_BINOP_MULTIPLY, 0, m, &cBinop_W5AIKOVe_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Qufgb4wd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GpwtMzf0, HV_BINOP_MULTIPLY, 0, m, &cBinop_GpwtMzf0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ikDmfXZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rymBI8dZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_rymBI8dZ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_dnrRv1jA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P1KTxKVq, HV_BINOP_MULTIPLY, 0, m, &cBinop_P1KTxKVq_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_WS4MPTOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pFpRcWns, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_QTPksB5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Mx1SbvoR, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_vRRb10SF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_78Kyg53w, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_szz5s7UI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CFGW14yJ, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_DuVtnFoy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s57KYiHu, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_EhSgZdKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oWI2AiJr_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_oWI2AiJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bOnhr2u4, HV_BINOP_DIVIDE, 1, m, &cBinop_bOnhr2u4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JqzN50sy_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_2NmS9WNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_gn7rnptX_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_FxS9yUTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_2NmS9WNR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gn7rnptX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bOnhr2u4, HV_BINOP_DIVIDE, 0, m, &cBinop_bOnhr2u4_sendMessage);
}

void Heavy_WSTD_3Q::cCast_JqzN50sy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FxS9yUTH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_bOnhr2u4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_20hmtwIx, HV_BINOP_MULTIPLY, 1, m, &cBinop_20hmtwIx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_20hmtwIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z8joyTmI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FwY3Im3P_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_V0ZSpmLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Q9UrJwy8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_xgW8Wju2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_z4i0XUHL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_i0OTMGo7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_N3hkwnI2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_N3hkwnI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_20hmtwIx, HV_BINOP_MULTIPLY, 0, m, &cBinop_20hmtwIx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YFc7iLeM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_WRDjO9pT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WRDjO9pT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R5jv1uHN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_MQk5gk0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yEJwWGEu, HV_BINOP_MULTIPLY, 1, m, &cBinop_yEJwWGEu_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_WqMW9WvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_60wyzdgF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_60wyzdgF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_MQk5gk0N_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ftpAlTv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_3lZujtZ4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3lZujtZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b0q2fhxl, HV_BINOP_MULTIPLY, 1, m, &cBinop_b0q2fhxl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wY03nKLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hir7HkhG, HV_BINOP_MULTIPLY, 1, m, &cBinop_hir7HkhG_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ocMxscQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_0iIex6HI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0iIex6HI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_wY03nKLj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lLj5ZqZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RfZ2Jw2K, 1, m, &cVar_RfZ2Jw2K_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JtUdBxM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F1vEUmri, HV_BINOP_MULTIPLY, 1, m, &cBinop_F1vEUmri_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_rxO55a3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_r5wI7XCm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_r5wI7XCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dhg8ly94, HV_BINOP_MULTIPLY, 1, m, &cBinop_dhg8ly94_sendMessage);
}

void Heavy_WSTD_3Q::cVar_RfZ2Jw2K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oYLz6m0f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_LgFwJY1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CW7pkkFZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_i0OTMGo7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TIQplLv2_sendMessage);
}

void Heavy_WSTD_3Q::cVar_ChSRPxOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_YFc7iLeM_sendMessage);
}

void Heavy_WSTD_3Q::cCast_z8joyTmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_V0ZSpmLu_sendMessage);
}

void Heavy_WSTD_3Q::cCast_FwY3Im3P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_xgW8Wju2_sendMessage);
}

void Heavy_WSTD_3Q::cSend_Q9UrJwy8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SYfO7hc8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_z4i0XUHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jyTeTrlP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_OwmwKMkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EQ0kcMJt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_R5jv1uHN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_UAY4ojDX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UAY4ojDX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yNFEHRGz, HV_BINOP_MULTIPLY, 1, m, &cBinop_yNFEHRGz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yNFEHRGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_1kWz4vXY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1kWz4vXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OwmwKMkD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_oYLz6m0f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_kNnqC38d_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kNnqC38d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2RDCQ4YY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4vKPFacn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ks3sUa5Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wCtbaTHO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yZA7g177_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4PpuKxRw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yEJwWGEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WS4MPTOw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_b0q2fhxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QTPksB5j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_hir7HkhG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vRRb10SF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_F1vEUmri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_szz5s7UI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_dhg8ly94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DuVtnFoy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_KGmlLhry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ChSRPxOL, 1, m, &cVar_ChSRPxOL_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yQUEa8YL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LgFwJY1R, 0, m, &cVar_LgFwJY1R_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yZA7g177_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b0q2fhxl, HV_BINOP_MULTIPLY, 0, m, &cBinop_b0q2fhxl_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ks3sUa5Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F1vEUmri, HV_BINOP_MULTIPLY, 0, m, &cBinop_F1vEUmri_sendMessage);
}

void Heavy_WSTD_3Q::cCast_wCtbaTHO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hir7HkhG, HV_BINOP_MULTIPLY, 0, m, &cBinop_hir7HkhG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_4vKPFacn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dhg8ly94, HV_BINOP_MULTIPLY, 0, m, &cBinop_dhg8ly94_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2RDCQ4YY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_4PpuKxRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yEJwWGEu, HV_BINOP_MULTIPLY, 0, m, &cBinop_yEJwWGEu_sendMessage);
}

void Heavy_WSTD_3Q::cCast_TIQplLv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RfZ2Jw2K, 0, m, &cVar_RfZ2Jw2K_sendMessage);
}

void Heavy_WSTD_3Q::cCast_CW7pkkFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ChSRPxOL, 0, m, &cVar_ChSRPxOL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_R0LKoVkt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cTWn5Rf0, 1, m, &cIf_cTWn5Rf0_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_GzpB8M2O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_gaFxM8l2, m);
}

void Heavy_WSTD_3Q::cBinop_jQ0hiYBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GzpB8M2O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Esi1aqXx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cTWn5Rf0, 0, m, &cIf_cTWn5Rf0_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_IEobt35M_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gU19ehjC, 0, m, &cSlice_gU19ehjC_sendMessage);
      break;
    }
    default: {
      cSwitchcase_RWyg1Ym2_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_gU19ehjC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_a1V3kPtF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_a1V3kPtF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_DTiWvcJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_a1V3kPtF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_a1V3kPtF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TYtJaBQi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_c3DQ87W7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_cO6BiIjA_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_hCNHsc4Y, 0, m, &cIf_hCNHsc4Y_sendMessage);
}

void Heavy_WSTD_3Q::cIf_hCNHsc4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_iemllIsl_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_fYTQpExb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_O9iMPImu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_qv0tD9CO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_MXEil7Ia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_k2pRw2ss, HV_BINOP_POW, 0, m, &cBinop_k2pRw2ss_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_k2pRw2ss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_b3cgc7lB, 0, m, &cIf_b3cgc7lB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZQwvMaiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_yufqshcc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_AkpNi8Wb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fYTQpExb, 0, m, &cIf_fYTQpExb_sendMessage);
}

void Heavy_WSTD_3Q::cCast_e1GZSTKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_O2B1lfEY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_O2B1lfEY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fYTQpExb, 1, m, &cIf_fYTQpExb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qv0tD9CO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_ZQwvMaiE_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_O9iMPImu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_b3cgc7lB, 0, m, &cIf_b3cgc7lB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yufqshcc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k2pRw2ss, HV_BINOP_POW, 1, m, &cBinop_k2pRw2ss_sendMessage);
  cMsg_MXEil7Ia_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_b3cgc7lB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_nOaH63ok, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_cO6BiIjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hCNHsc4Y, 1, m, &cIf_hCNHsc4Y_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iemllIsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4UnkZUXM, HV_BINOP_GREATER_THAN, 1, m, &cBinop_4UnkZUXM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_nV0Bk824, HV_BINOP_EQ, 1, m, &cBinop_nV0Bk824_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_0eejBm3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_X8aKVUiU, HV_BINOP_ADD, 0, m, &cBinop_X8aKVUiU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_X8aKVUiU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e1GZSTKD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AkpNi8Wb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4UnkZUXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_b3cgc7lB, 1, m, &cIf_b3cgc7lB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nV0Bk824_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9a1ne4kQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_9a1ne4kQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_nOaH63ok, m);
}

void Heavy_WSTD_3Q::cCast_QRcWObmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0eejBm3u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_yGD2c5Tg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X8aKVUiU, HV_BINOP_ADD, 1, m, &cBinop_X8aKVUiU_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4UnkZUXM, HV_BINOP_GREATER_THAN, 0, m, &cBinop_4UnkZUXM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_nV0Bk824, HV_BINOP_EQ, 0, m, &cBinop_nV0Bk824_sendMessage);
}

void Heavy_WSTD_3Q::cCast_o7zaMfPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_c3DQ87W7, 0, m, &cVar_c3DQ87W7_sendMessage);
}

void Heavy_WSTD_3Q::cVar_tMZqMRlO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZABYhuTQ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_45yHOFK2, 0, m, &cIf_45yHOFK2_sendMessage);
}

void Heavy_WSTD_3Q::cIf_45yHOFK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_uS9jeZJv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_INjT0dDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_aFuSjJpF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_5nev20IX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_84Drw3lE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SgDDUBVf, HV_BINOP_POW, 0, m, &cBinop_SgDDUBVf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SgDDUBVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dk4sexAs, 0, m, &cIf_dk4sexAs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HpPRGxJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_rG3V957N_sendMessage);
}

void Heavy_WSTD_3Q::cCast_jM8oXHYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_INjT0dDO, 0, m, &cIf_INjT0dDO_sendMessage);
}

void Heavy_WSTD_3Q::cCast_uVC2MiIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_knsOEo4g_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_knsOEo4g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_INjT0dDO, 1, m, &cIf_INjT0dDO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5nev20IX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_HpPRGxJ6_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_aFuSjJpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_dk4sexAs, 0, m, &cIf_dk4sexAs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rG3V957N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SgDDUBVf, HV_BINOP_POW, 1, m, &cBinop_SgDDUBVf_sendMessage);
  cMsg_84Drw3lE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_dk4sexAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ejIxRizH_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dOqUznjH_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_4NtxR0j5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_ZABYhuTQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_45yHOFK2, 1, m, &cIf_45yHOFK2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_uS9jeZJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MpNWhf0f, HV_BINOP_GREATER_THAN, 1, m, &cBinop_MpNWhf0f_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_v5nBibl0, HV_BINOP_EQ, 1, m, &cBinop_v5nBibl0_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_KzFCe4yQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_iawutD4j, HV_BINOP_ADD, 0, m, &cBinop_iawutD4j_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iawutD4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uVC2MiIi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jM8oXHYt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MpNWhf0f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dk4sexAs, 1, m, &cIf_dk4sexAs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_v5nBibl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sk9AyX93_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_sk9AyX93_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ejIxRizH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dOqUznjH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_4NtxR0j5_sendMessage);
}

void Heavy_WSTD_3Q::cCast_T7zuH9dC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tMZqMRlO, 0, m, &cVar_tMZqMRlO_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yyquJfBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iawutD4j, HV_BINOP_ADD, 1, m, &cBinop_iawutD4j_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MpNWhf0f, HV_BINOP_GREATER_THAN, 0, m, &cBinop_MpNWhf0f_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_v5nBibl0, HV_BINOP_EQ, 0, m, &cBinop_v5nBibl0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_l08HVt5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KzFCe4yQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_6zfdBu88_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Oa0ba5LP_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_0k9k1H8D, 0, m, &cIf_0k9k1H8D_sendMessage);
}

void Heavy_WSTD_3Q::cIf_0k9k1H8D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Y7ivzLOc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_YqySUZwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_l2heJiHB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_o1BTglSC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_Htt4GBLW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_k2bIUYaN, HV_BINOP_POW, 0, m, &cBinop_k2bIUYaN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_k2bIUYaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3Bo5Nkap, 0, m, &cIf_3Bo5Nkap_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GFo88sso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_gMWwBes6_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Fwpf6vHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YqySUZwF, 0, m, &cIf_YqySUZwF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_N6huYg6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Z4E9hFsz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Z4E9hFsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YqySUZwF, 1, m, &cIf_YqySUZwF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_o1BTglSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_GFo88sso_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_l2heJiHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_3Bo5Nkap, 0, m, &cIf_3Bo5Nkap_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gMWwBes6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k2bIUYaN, HV_BINOP_POW, 1, m, &cBinop_k2bIUYaN_sendMessage);
  cMsg_Htt4GBLW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_3Bo5Nkap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_wN6yYYsg, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_Oa0ba5LP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0k9k1H8D, 1, m, &cIf_0k9k1H8D_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Y7ivzLOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d2DLzwQX, HV_BINOP_GREATER_THAN, 1, m, &cBinop_d2DLzwQX_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yNq27SeB, HV_BINOP_EQ, 1, m, &cBinop_yNq27SeB_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_qU3hG3Vf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GGhjsGeY, HV_BINOP_ADD, 0, m, &cBinop_GGhjsGeY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GGhjsGeY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N6huYg6w_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fwpf6vHM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_d2DLzwQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3Bo5Nkap, 1, m, &cIf_3Bo5Nkap_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yNq27SeB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yfQVjPCu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_yfQVjPCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wN6yYYsg, m);
}

void Heavy_WSTD_3Q::cCast_Y6qceCCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qU3hG3Vf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_sbpgB5y9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GGhjsGeY, HV_BINOP_ADD, 1, m, &cBinop_GGhjsGeY_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_d2DLzwQX, HV_BINOP_GREATER_THAN, 0, m, &cBinop_d2DLzwQX_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yNq27SeB, HV_BINOP_EQ, 0, m, &cBinop_yNq27SeB_sendMessage);
}

void Heavy_WSTD_3Q::cCast_OHnTXri8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6zfdBu88, 0, m, &cVar_6zfdBu88_sendMessage);
}

void Heavy_WSTD_3Q::cIf_iignx3Gg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_P2Xl2VQ6, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_gl118SUM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_euSTgymp, 0, m, &cSlice_euSTgymp_sendMessage);
      break;
    }
    default: {
      cSwitchcase_oMXoNEOd_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_euSTgymp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pfKHMlqn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pfKHMlqn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_iiVmBfzb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pfKHMlqn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_pfKHMlqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hS7lyUnL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_oMXoNEOd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DjVp4722, 0, m, &cSlice_DjVp4722_sendMessage);
      break;
    }
    default: {
      cSwitchcase_IEobt35M_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_DjVp4722_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_aRfdHn4B_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_aRfdHn4B_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_Z5TXTVex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aRfdHn4B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_aRfdHn4B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FpmVps5e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_RWyg1Ym2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vB9qB3MX, 0, m, &cSlice_vB9qB3MX_sendMessage);
      break;
    }
    default: {
      cSwitchcase_kjQF4IoV_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_vB9qB3MX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_wYtdebag_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_wYtdebag_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_QxKBERj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wYtdebag_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_wYtdebag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KjbYDFNH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_kjQF4IoV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2GFeHoo5, 0, m, &cSlice_2GFeHoo5_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_2GFeHoo5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_TXhKJe9j_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_TXhKJe9j_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_1njI2lqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TXhKJe9j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_TXhKJe9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Iflo0g16_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_QzxaCk1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6dhMzCot, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_cD8vJsEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2kqArO3G, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_ooAMh5li_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CdTBkT5S, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_ZDn0D8HZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hiN9cr4n, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Ep4c1Ldi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QlcXaDWA, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_qDNycf9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Kq5Sk465_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_Kq5Sk465_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nTZb6w6m, HV_BINOP_DIVIDE, 1, m, &cBinop_nTZb6w6m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3p06Jsuv_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_xBRA7UOk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_2V0Y4izh_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_RZSZ8NX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_xBRA7UOk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2V0Y4izh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nTZb6w6m, HV_BINOP_DIVIDE, 0, m, &cBinop_nTZb6w6m_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3p06Jsuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RZSZ8NX2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_nTZb6w6m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nkEvDhve, HV_BINOP_MULTIPLY, 1, m, &cBinop_nkEvDhve_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nkEvDhve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0U9QLf77_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fdr0gGSy_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_vJ192wEY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_e6zMpMNx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_FC38wTJ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IkxobNU9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_nl2oC9ag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_3e8A0lWo_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3e8A0lWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nkEvDhve, HV_BINOP_MULTIPLY, 0, m, &cBinop_nkEvDhve_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vnNIkDfL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_GQi2vcoB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GQi2vcoB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZzYR2JuA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_0bod6czK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5ACX61E6, 1, m, &cVar_5ACX61E6_sendMessage);
}

void Heavy_WSTD_3Q::cVar_5ACX61E6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n07OmRKg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_YhAFoJ8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N5Hf2p4S, HV_BINOP_MULTIPLY, 1, m, &cBinop_N5Hf2p4S_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1O8QgD3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_YhAFoJ8R_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AEbxkFJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_3xT5FRPD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3xT5FRPD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h8wccjne, HV_BINOP_MULTIPLY, 1, m, &cBinop_h8wccjne_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KRRw9Siz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lf7dty8f, HV_BINOP_MULTIPLY, 1, m, &cBinop_lf7dty8f_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7v9BoCON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_KRRw9Siz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wqRD8vch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2VfysnYM, HV_BINOP_MULTIPLY, 1, m, &cBinop_2VfysnYM_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_zDUGhC4r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_aI1vPQ4u_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aI1vPQ4u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UgrPaUeK, HV_BINOP_MULTIPLY, 1, m, &cBinop_UgrPaUeK_sendMessage);
}

void Heavy_WSTD_3Q::cVar_y3ecMgaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EMBxVSiy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_nl2oC9ag_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bkBo0ueb_sendMessage);
}

void Heavy_WSTD_3Q::cVar_oYrD3ALX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_vnNIkDfL_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0U9QLf77_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_vJ192wEY_sendMessage);
}

void Heavy_WSTD_3Q::cCast_fdr0gGSy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_FC38wTJ3_sendMessage);
}

void Heavy_WSTD_3Q::cSend_e6zMpMNx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_faW0Mxu8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_IkxobNU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fOY3gcIE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_eBo2s8Ps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QnNAmdaE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_ZzYR2JuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_6YjzVdCI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6YjzVdCI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eG7dhB9H, HV_BINOP_MULTIPLY, 1, m, &cBinop_eG7dhB9H_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eG7dhB9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_R0OL8f3d_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_R0OL8f3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eBo2s8Ps_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_n07OmRKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ytQMTBph_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ytQMTBph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_llDhSA3J_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_01q8amSr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8SjUMoCi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VMGhv7dK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mHWLE2ft_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N02SOeld_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_N5Hf2p4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QzxaCk1o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_h8wccjne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cD8vJsEa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_lf7dty8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ooAMh5li_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_2VfysnYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZDn0D8HZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_UgrPaUeK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ep4c1Ldi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_d0PRIplq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oYrD3ALX, 1, m, &cVar_oYrD3ALX_sendMessage);
}

void Heavy_WSTD_3Q::cCast_dQ4Ga8aq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_y3ecMgaN, 0, m, &cVar_y3ecMgaN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_mHWLE2ft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h8wccjne, HV_BINOP_MULTIPLY, 0, m, &cBinop_h8wccjne_sendMessage);
}

void Heavy_WSTD_3Q::cCast_llDhSA3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_8SjUMoCi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2VfysnYM, HV_BINOP_MULTIPLY, 0, m, &cBinop_2VfysnYM_sendMessage);
}

void Heavy_WSTD_3Q::cCast_VMGhv7dK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lf7dty8f, HV_BINOP_MULTIPLY, 0, m, &cBinop_lf7dty8f_sendMessage);
}

void Heavy_WSTD_3Q::cCast_N02SOeld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N5Hf2p4S, HV_BINOP_MULTIPLY, 0, m, &cBinop_N5Hf2p4S_sendMessage);
}

void Heavy_WSTD_3Q::cCast_01q8amSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UgrPaUeK, HV_BINOP_MULTIPLY, 0, m, &cBinop_UgrPaUeK_sendMessage);
}

void Heavy_WSTD_3Q::cCast_bkBo0ueb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5ACX61E6, 0, m, &cVar_5ACX61E6_sendMessage);
}

void Heavy_WSTD_3Q::cCast_EMBxVSiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oYrD3ALX, 0, m, &cVar_oYrD3ALX_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Zmyh8YSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vxW4LWll, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_xFxsv4ZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3wqv4dRv, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_tcL6ayZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v597Oqam, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_LcuL1hGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4SFwmirq, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_XQffKOrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YPvXfvaw_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_YPvXfvaw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GB3dlVKl, HV_BINOP_DIVIDE, 1, m, &cBinop_GB3dlVKl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZsO62d5O_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_tO7Blw8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_vEjo5Tbv_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_9i7I2sT9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_tO7Blw8e_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vEjo5Tbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GB3dlVKl, HV_BINOP_DIVIDE, 0, m, &cBinop_GB3dlVKl_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZsO62d5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9i7I2sT9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_GB3dlVKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Cdh2ip34, HV_BINOP_MULTIPLY, 1, m, &cBinop_Cdh2ip34_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Cdh2ip34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N1HriGTU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FuV9WI0B_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_0hBgKqiU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1b8Clela_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_4QO6Xg2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xIASFdHC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_yNSPjVVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_ID6kjKXr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ID6kjKXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Cdh2ip34, HV_BINOP_MULTIPLY, 0, m, &cBinop_Cdh2ip34_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NRUalJev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_PigsOIwM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PigsOIwM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QYKezrod_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_kSNLvh0P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z26JEh1R, HV_BINOP_MULTIPLY, 1, m, &cBinop_Z26JEh1R_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8l6wrzCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SfehNY3I, 1, m, &cVar_SfehNY3I_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kQI6oaTr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IOBaI3JB, HV_BINOP_MULTIPLY, 1, m, &cBinop_IOBaI3JB_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_1ogATBV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_U7OzZipx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_U7OzZipx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3WqD4raG, HV_BINOP_MULTIPLY, 1, m, &cBinop_3WqD4raG_sendMessage);
}

void Heavy_WSTD_3Q::cVar_SfehNY3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RuE4mWBF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_Y8tpfoPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BVaDPPT8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_yNSPjVVe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4wmqiPEN_sendMessage);
}

void Heavy_WSTD_3Q::cVar_mp9kLysR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_NRUalJev_sendMessage);
}

void Heavy_WSTD_3Q::cCast_N1HriGTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_0hBgKqiU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_FuV9WI0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_4QO6Xg2o_sendMessage);
}

void Heavy_WSTD_3Q::cSend_1b8Clela_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_G22QdiET_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_xIASFdHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ujgjf8Gl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_B0NKqChS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dgexVbqi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_QYKezrod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_JpGodCbq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JpGodCbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_StXLiDVi, HV_BINOP_MULTIPLY, 1, m, &cBinop_StXLiDVi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_StXLiDVi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_wLDlEmbU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wLDlEmbU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_B0NKqChS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_RuE4mWBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wRVN1jrQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wRVN1jrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3n89WB8L_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QYJREQLv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wgz5xiWQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_21JRg3p3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VbtUE1Ar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zmyh8YSR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Z26JEh1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xFxsv4ZQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_IOBaI3JB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tcL6ayZK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_3WqD4raG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LcuL1hGk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_ZcFiVV2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mp9kLysR, 1, m, &cVar_mp9kLysR_sendMessage);
}

void Heavy_WSTD_3Q::cCast_KOZtplzP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y8tpfoPB, 0, m, &cVar_Y8tpfoPB_sendMessage);
}

void Heavy_WSTD_3Q::cCast_4wmqiPEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SfehNY3I, 0, m, &cVar_SfehNY3I_sendMessage);
}

void Heavy_WSTD_3Q::cCast_BVaDPPT8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mp9kLysR, 0, m, &cVar_mp9kLysR_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3n89WB8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3WqD4raG, HV_BINOP_MULTIPLY, 0, m, &cBinop_3WqD4raG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_QYJREQLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IOBaI3JB, HV_BINOP_MULTIPLY, 0, m, &cBinop_IOBaI3JB_sendMessage);
}

void Heavy_WSTD_3Q::cCast_21JRg3p3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VbtUE1Ar, HV_BINOP_MULTIPLY, 0, m, &cBinop_VbtUE1Ar_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Wgz5xiWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z26JEh1R, HV_BINOP_MULTIPLY, 0, m, &cBinop_Z26JEh1R_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_CJhbnzLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_N1XWIGe2, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_c1CLX1pI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zGjelxwf, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_S9Y7bdvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7blWAaSD, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_MQaR5ndl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3uBq9Lvk, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_bb7UK5cF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_i2fUtcKF, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_nxlJhdER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QoxqmP3J_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_QoxqmP3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R3gvYVON, HV_BINOP_DIVIDE, 1, m, &cBinop_R3gvYVON_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sPa9hLII_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_N9W5y27V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_lcYujyJz_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_akpiL3wg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_N9W5y27V_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lcYujyJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R3gvYVON, HV_BINOP_DIVIDE, 0, m, &cBinop_R3gvYVON_sendMessage);
}

void Heavy_WSTD_3Q::cCast_sPa9hLII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_akpiL3wg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_R3gvYVON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CJzBlbU5, HV_BINOP_MULTIPLY, 1, m, &cBinop_CJzBlbU5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CJzBlbU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YPizLm0u_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bJ8AhKnf_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_2dunwfM3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pZRUKR1c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_Rsja1oQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eVHvlOp8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_E4Dt1efc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_rcFiL0lz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rcFiL0lz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CJzBlbU5, HV_BINOP_MULTIPLY, 0, m, &cBinop_CJzBlbU5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_duGy0c6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_k1NqZPPL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_k1NqZPPL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Khtu1phz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_KWXyH6Tc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NUbewmt5, HV_BINOP_MULTIPLY, 1, m, &cBinop_NUbewmt5_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_4lcy0245_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_aXgzUYht_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aXgzUYht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_KWXyH6Tc_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_OweSOtSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_gTY41RCS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gTY41RCS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OrB35BRi, HV_BINOP_MULTIPLY, 1, m, &cBinop_OrB35BRi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qDCzAWWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Awvtwpk, HV_BINOP_MULTIPLY, 1, m, &cBinop_2Awvtwpk_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_kub6441d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_iSqZhIQ6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iSqZhIQ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qDCzAWWZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gHDOIcbc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_d0StjQ6J, 1, m, &cVar_d0StjQ6J_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zmBOPysX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_deSQi2J1, HV_BINOP_MULTIPLY, 1, m, &cBinop_deSQi2J1_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_9ikqfhD9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_AcwGRtI5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AcwGRtI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sA4DfsYE, HV_BINOP_MULTIPLY, 1, m, &cBinop_sA4DfsYE_sendMessage);
}

void Heavy_WSTD_3Q::cVar_d0StjQ6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x3V6MAXt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_ZnpTNV6M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eD7qj5ps_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_E4Dt1efc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u2BGbuzP_sendMessage);
}

void Heavy_WSTD_3Q::cVar_yiGAIYEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_duGy0c6k_sendMessage);
}

void Heavy_WSTD_3Q::cCast_YPizLm0u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_2dunwfM3_sendMessage);
}

void Heavy_WSTD_3Q::cCast_bJ8AhKnf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_Rsja1oQI_sendMessage);
}

void Heavy_WSTD_3Q::cSend_pZRUKR1c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yEy1CvuU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_eVHvlOp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_c0KyIi6M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_1MYNJ9gD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ULvsi50h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_Khtu1phz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_FrqXzy8i_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FrqXzy8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DaCJ8Tjp, HV_BINOP_MULTIPLY, 1, m, &cBinop_DaCJ8Tjp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DaCJ8Tjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ReS3Uqtm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ReS3Uqtm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1MYNJ9gD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_x3V6MAXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0Vb6saVT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0Vb6saVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_73atBAcr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xDDqgk8z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TEWGKCJH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RFWXSEHJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dFFl76p7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2QvSksGM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NUbewmt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CJhbnzLC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_OrB35BRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c1CLX1pI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_2Awvtwpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S9Y7bdvH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_deSQi2J1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MQaR5ndl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_sA4DfsYE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bb7UK5cF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_oYE6HqNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yiGAIYEK, 1, m, &cVar_yiGAIYEK_sendMessage);
}

void Heavy_WSTD_3Q::cCast_bds60T7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZnpTNV6M, 0, m, &cVar_ZnpTNV6M_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2QvSksGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NUbewmt5, HV_BINOP_MULTIPLY, 0, m, &cBinop_NUbewmt5_sendMessage);
}

void Heavy_WSTD_3Q::cCast_xDDqgk8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sA4DfsYE, HV_BINOP_MULTIPLY, 0, m, &cBinop_sA4DfsYE_sendMessage);
}

void Heavy_WSTD_3Q::cCast_RFWXSEHJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Awvtwpk, HV_BINOP_MULTIPLY, 0, m, &cBinop_2Awvtwpk_sendMessage);
}

void Heavy_WSTD_3Q::cCast_73atBAcr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_TEWGKCJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_deSQi2J1, HV_BINOP_MULTIPLY, 0, m, &cBinop_deSQi2J1_sendMessage);
}

void Heavy_WSTD_3Q::cCast_dFFl76p7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OrB35BRi, HV_BINOP_MULTIPLY, 0, m, &cBinop_OrB35BRi_sendMessage);
}

void Heavy_WSTD_3Q::cCast_u2BGbuzP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_d0StjQ6J, 0, m, &cVar_d0StjQ6J_sendMessage);
}

void Heavy_WSTD_3Q::cCast_eD7qj5ps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yiGAIYEK, 0, m, &cVar_yiGAIYEK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ejIxRizH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iignx3Gg, 1, m, &cIf_iignx3Gg_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_UW6W2dkh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_P2Xl2VQ6, m);
}

void Heavy_WSTD_3Q::cBinop_dOqUznjH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UW6W2dkh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_4NtxR0j5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iignx3Gg, 0, m, &cIf_iignx3Gg_sendMessage);
}

void Heavy_WSTD_3Q::cVar_lHY20qsq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_27crII6x, HV_BINOP_DIVIDE, 0, m, &cBinop_27crII6x_sendMessage);
}

void Heavy_WSTD_3Q::cVar_GiSrLIRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kPJmP7TO, HV_BINOP_DIVIDE, 1, m, &cBinop_kPJmP7TO_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_27crII6x, HV_BINOP_DIVIDE, 1, m, &cBinop_27crII6x_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_o88GGoSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eqpY4BBU, HV_BINOP_DIVIDE, 0, m, &cBinop_eqpY4BBU_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_ExETt4Of_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eqpY4BBU, HV_BINOP_DIVIDE, 1, m, &cBinop_eqpY4BBU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_07PqmlgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lHY20qsq, 0, m, &cVar_lHY20qsq_sendMessage);
}

void Heavy_WSTD_3Q::cCast_pOnm00Gs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GiSrLIRP, 0, m, &cVar_GiSrLIRP_sendMessage);
}

void Heavy_WSTD_3Q::cCast_L1DlRq50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kPJmP7TO, HV_BINOP_DIVIDE, 0, m, &cBinop_kPJmP7TO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kPJmP7TO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_o88GGoSi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_27crII6x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_ExETt4Of_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eqpY4BBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_ktULEVFv_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_vGdXi1TH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_xQTQjlyv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_C79w3AQf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_yKbzyjDc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ktULEVFv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_C79w3AQf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yKbzyjDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_vGdXi1TH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xQTQjlyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lQPTlMHd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_LeGb8oHJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_hM9chQTo_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_gl118SUM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_sFxVbo4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_hM9chQTo_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_gl118SUM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_UHD1d5GE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_hM9chQTo_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_gl118SUM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_VbDfmBy7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_hM9chQTo_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_gl118SUM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_lQPTlMHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_hM9chQTo_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_gl118SUM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_2z3TmCAo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_BtpvP7q4, 0, m, &cVar_BtpvP7q4_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_OjWbVBrq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_cUIezvV7, 0, m, &cVar_cUIezvV7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1KsnFI01, 0, m, &cVar_1KsnFI01_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WQHKiwk2, 0, m, &cVar_WQHKiwk2_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_3Gugb2qn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cUIezvV7, 0, m, &cVar_cUIezvV7_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_aQ19JBQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1KsnFI01, 0, m, &cVar_1KsnFI01_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_nmMEGfHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WQHKiwk2, 0, m, &cVar_WQHKiwk2_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_7i0kAQyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_P1rhF2JN, 0, m, &cVar_P1rhF2JN_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_PiS0RvqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dYGyM5r7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P9swUKS5_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_F3RHDmo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YzP0nOpC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KD7ppAwr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QRCidf0Y_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_5sKY9880_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WdREiXMv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rvCBLlo1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ByGDPRDF_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_0whNdDET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A3P5cuRs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yZkPyEzb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PEYBubvP_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_YGyxY8kz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7zut5CtL_sendMessage(_c, 0, m);
  cMsg_zlUwS56B_sendMessage(_c, 0, m);
  cMsg_EhSgZdKz_sendMessage(_c, 0, m);
  cMsg_qDNycf9Y_sendMessage(_c, 0, m);
  cMsg_XQffKOrh_sendMessage(_c, 0, m);
  cMsg_nxlJhdER_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_BOtuSODI, 0, m, &cVar_BOtuSODI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_P1rhF2JN, 0, m, &cVar_P1rhF2JN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LgFwJY1R, 0, m, &cVar_LgFwJY1R_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_y3ecMgaN, 0, m, &cVar_y3ecMgaN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Y8tpfoPB, 0, m, &cVar_Y8tpfoPB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZnpTNV6M, 0, m, &cVar_ZnpTNV6M_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ys9jxgud, 0, m, &cVar_ys9jxgud_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MCKSVMn8, 0, m, &cVar_MCKSVMn8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wv6WW2Ba, 0, m, &cVar_wv6WW2Ba_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wTYeE4ON, 0, m, &cVar_wTYeE4ON_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aQbNrOb7, 0, m, &cVar_aQbNrOb7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wPC3SQ3v, 0, m, &cVar_wPC3SQ3v_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HJqxy73v, 0, m, &cVar_HJqxy73v_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Dk1QwCJb, 0, m, &cVar_Dk1QwCJb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DTiWvcJg, 0, m, &cVar_DTiWvcJg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_c3DQ87W7, 0, m, &cVar_c3DQ87W7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tMZqMRlO, 0, m, &cVar_tMZqMRlO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6zfdBu88, 0, m, &cVar_6zfdBu88_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iiVmBfzb, 0, m, &cVar_iiVmBfzb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Z5TXTVex, 0, m, &cVar_Z5TXTVex_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QxKBERj8, 0, m, &cVar_QxKBERj8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1njI2lqr, 0, m, &cVar_1njI2lqr_sendMessage);
  cMsg_OjWbVBrq_sendMessage(_c, 0, m);
  cMsg_2z3TmCAo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_vtc5bGpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PmzaG30G, HV_BINOP_MULTIPLY, 0, m, &cBinop_PmzaG30G_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_bCAlAxRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_cLRYdOrh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_U7PDIwcV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_8XswOpHC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_nmqFbhBi_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_20vKAKem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_I6AmYcpO_sendMessage);
  cMsg_Vdzu6LQy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_8eZXjP9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1WbacYbx, HV_BINOP_MULTIPLY, 0, m, &cBinop_1WbacYbx_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_YyvDhqZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_QRx9ehEJ_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_3mo4gYW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W5AIKOVe, HV_BINOP_MULTIPLY, 1, m, &cBinop_W5AIKOVe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_n2KTiHZO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_lz4XMFQI_sendMessage);
  cMsg_fU7Q9J1P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_SYfO7hc8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yNFEHRGz, HV_BINOP_MULTIPLY, 0, m, &cBinop_yNFEHRGz_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_jyTeTrlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WqMW9WvY_sendMessage(_c, 0, m);
  cMsg_ftpAlTv9_sendMessage(_c, 0, m);
  cMsg_ocMxscQl_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_JtUdBxM5_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_EQ0kcMJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_lLj5ZqZR_sendMessage);
  cMsg_rxO55a3d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_TYtJaBQi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y8tpfoPB, 0, m, &cVar_Y8tpfoPB_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_Iflo0g16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZcFiVV2M_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KOZtplzP_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_hS7lyUnL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o7zaMfPG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yGD2c5Tg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QRcWObmE_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_KjbYDFNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OHnTXri8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sbpgB5y9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y6qceCCP_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_FpmVps5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T7zuH9dC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yyquJfBB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l08HVt5A_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_faW0Mxu8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eG7dhB9H, HV_BINOP_MULTIPLY, 0, m, &cBinop_eG7dhB9H_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_fOY3gcIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_1O8QgD3C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_AEbxkFJr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_7v9BoCON_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_wqRD8vch_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_QnNAmdaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_0bod6czK_sendMessage);
  cMsg_zDUGhC4r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_G22QdiET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_StXLiDVi, HV_BINOP_MULTIPLY, 0, m, &cBinop_StXLiDVi_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_Ujgjf8Gl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_kQI6oaTr_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_dgexVbqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VbtUE1Ar, HV_BINOP_MULTIPLY, 1, m, &cBinop_VbtUE1Ar_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_kSNLvh0P_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_8l6wrzCA_sendMessage);
  cMsg_1ogATBV0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_yEy1CvuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DaCJ8Tjp, HV_BINOP_MULTIPLY, 0, m, &cBinop_DaCJ8Tjp_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_c0KyIi6M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4lcy0245_sendMessage(_c, 0, m);
  cMsg_OweSOtSP_sendMessage(_c, 0, m);
  cMsg_kub6441d_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_zmBOPysX_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ULvsi50h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_gHDOIcbc_sendMessage);
  cMsg_9ikqfhD9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_6YwvAd6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BtpvP7q4, 0, m, &cVar_BtpvP7q4_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_3Q::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9;

  // input and output vars
  hv_bufferf_t O0, O1, O2, O3, O4, O5;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));
    __hv_zero_f(VOf(O2));
    __hv_zero_f(VOf(O3));
    __hv_zero_f(VOf(O4));
    __hv_zero_f(VOf(O5));

    // process all signal functions
    __hv_line_f(&sLine_eOgXnkcJ, VOf(Bf0));
    __hv_line_f(&sLine_i34V4NBz, VOf(Bf1));
    __hv_line_f(&sLine_p3r9zwH1, VOf(Bf2));
    __hv_line_f(&sLine_nCaPxbZz, VOf(Bf3));
    __hv_line_f(&sLine_nbcFF3HK, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_yBHByhHg, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_q6SzdLM0, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_IgbiGREg, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_PAVWumyt, VOf(Bf1));
    __hv_line_f(&sLine_fLirYtYr, VOf(Bf0));
    __hv_line_f(&sLine_uPIotyQx, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_uCkT4eYv, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_gaFxM8l2, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_pFpRcWns, VOf(Bf5));
    __hv_line_f(&sLine_Mx1SbvoR, VOf(Bf1));
    __hv_line_f(&sLine_78Kyg53w, VOf(Bf2));
    __hv_line_f(&sLine_CFGW14yJ, VOf(Bf4));
    __hv_line_f(&sLine_s57KYiHu, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_fSO6cUoF, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_lBlvx7Cw, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_6dhMzCot, VOf(Bf6));
    __hv_line_f(&sLine_2kqArO3G, VOf(Bf2));
    __hv_line_f(&sLine_CdTBkT5S, VOf(Bf1));
    __hv_line_f(&sLine_hiN9cr4n, VOf(Bf5));
    __hv_line_f(&sLine_QlcXaDWA, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_jLBjubCp, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_nOaH63ok, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_vxW4LWll, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_3wqv4dRv, VOf(Bf2));
    __hv_line_f(&sLine_v597Oqam, VOf(Bf6));
    __hv_line_f(&sLine_4SFwmirq, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_pKumtdg6, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_P2Xl2VQ6, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_N1XWIGe2, VOf(Bf8));
    __hv_line_f(&sLine_zGjelxwf, VOf(Bf2));
    __hv_line_f(&sLine_7blWAaSD, VOf(Bf1));
    __hv_line_f(&sLine_3uBq9Lvk, VOf(Bf7));
    __hv_line_f(&sLine_i2fUtcKF, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_y1c5Ra2w, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_wN6yYYsg, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf0), VIf(O2), VOf(O2));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf4), VIf(O4), VOf(O4));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf6), VIf(O3), VOf(O3));
    __hv_add_f(VIf(Bf7), VIf(O5), VOf(O5));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
    __hv_store_f(outputBuffers[2]+n, VIf(O2));
    __hv_store_f(outputBuffers[3]+n, VIf(O3));
    __hv_store_f(outputBuffers[4]+n, VIf(O4));
    __hv_store_f(outputBuffers[5]+n, VIf(O5));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_3Q::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 6 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(6*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);
  bOut[2] = outputBuffers+(2*n4);
  bOut[3] = outputBuffers+(3*n4);
  bOut[4] = outputBuffers+(4*n4);
  bOut[5] = outputBuffers+(5*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_3Q::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 6 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(6*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  
  // interleave the heavy output into the output buffer
  for (int i = 0; i < 6; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+6*j] = bOut[i*n4+j];
    }
  }

  return n;
}
